@@ -1,6 +1,6 @@
 /*
- * $Id: di.c,v 2.128 2013-01-18 08:32:05-08 bll Exp $
- * $Source: /home/bll/DI/di/C/RCS/di.c,v $
+ * $Id$
+ * $Source$
  *
  * Copyright 1994-2013 Brad Lanam, Walnut Creek, CA
  */
@@ -154,7 +154,8 @@
 
 #define DI_UNKNOWN_DEV          -1L
 
-int          debug = { 0 };
+extern int debug;
+int debug = { 0 };
 
 #if defined (__cplusplus) || defined (c_plusplus)
   extern "C" {
@@ -515,6 +516,9 @@ checkFileInfo (diData, optidx, argc, argv)
       }
     }
 
+    /* also turn off the -I and -x lists */
+    diData->includeList.count = 0;
+    diData->ignoreList.count = 0;
     return rc;
 }
 
