@@ -1,6 +1,6 @@
 /*
- * $Id: getoptn.c,v 1.12 2013-01-19 16:52:02-08 bll Exp $
- * $Source: /home/bll/DI/di/C/RCS/getoptn.c,v $
+ * $Id$
+ * $Source$
  * Copyright 2011-2013 Brad Lanam, Walnut Creek, CA
  */
 
@@ -1265,7 +1265,7 @@ main (argc, argv)
   optidx = getoptn (GETOPTN_LEGACY, ac, av,
        sizeof (opts) / sizeof (getoptn_opt_t), opts);
   if (i != 0 || j != 1) {
-    fprintf (stderr, "fail test %d\n");
+    fprintf (stderr, "fail test %d\n", testno);
     grc = 1;
   }
 
