@@ -1,7 +1,7 @@
 #!/bin/sh
 #
-# $Id: env-cc.sh,v 1.41 2013-01-17 17:11:13-08 bll Exp $
-# $Source: /home/bll/DI/di/mkconfig/units/RCS/env-cc.sh,v $
+# $Id$
+# $Source$
 #
 # Copyright 2001-2012 Brad Lanam, Walnut Creek, California USA
 #
@@ -196,7 +196,7 @@ check_cflags () {
       # -Wextra -Wno-unused-but-set-variable -Wno-unused-parameter
   fi
   if [ "${_MKCONFIG_USING_CLANG}" = Y ]; then
-     ccflags="-Wno-unknown-warning-option -Weverything -Wno-padded -Wno-format-nonliteral -Wno-cast-align -Wno-system-headers $ccflags"
+     ccflags="-Wno-unknown-warning-option -Weverything -Wno-padded -Wno-format-nonliteral -Wno-cast-align -Wno-system-headers -Wno-disabled-macro-expansion $ccflags"
   fi
 
   TCC=${CC}
@@ -424,7 +424,7 @@ check_shcflags () {
       HP-UX)
         shcflags="+Z $SHCFLAGS"
         ;;
-      Irix)
+      IRIX*)
         shcflags="-KPIC $SHCFLAGS"
         ;;
       OSF1)
@@ -460,7 +460,7 @@ check_shldflags () {
       HP-UX)
         shldflags="$SHLDFLAGS -b"
         ;;
-      Irix)
+      IRIX*)
         # "-shared"
         ;;
       OSF1)
@@ -500,7 +500,7 @@ check_sharednameflag () {
       HP-UX)
         SHLDNAMEFLAG="-Wl,+h "
         ;;
-      Irix)
+      IRIX*)
         # -soname
         ;;
       OSF1)
@@ -565,6 +565,9 @@ check_sharerunpathflag () {
       HP-UX)
         SHRUNPATH="-Wl,+b "
         ;;
+      IRIX*)
+        SHRUNPATH="-Wl,-rpath "
+        ;;
       OSF1)
         SHRUNPATH="-rpath "
         ;;
